# Generated by roxygen2: do not edit by hand

S3method(print,bluertopo_cache_clear)
S3method(print,bluertopo_downloads)
S3method(print,bluertopo_resolution)
S3method(print,bluertopo_result)
export(bluertopo)
export(bluertopo_cache_clear)
export(bluertopo_cache_dir)
export(bluertopo_download)
export(bluertopo_resolution)
export(bluertopo_tile_polygons)
export(bluertopo_tiles)
importFrom(terra,plot)
