## ----include=FALSE------------------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>", eval = FALSE)

## -----------------------------------------------------------------------------
# # Use every intersecting native source resolution.
# bluertopo(aoi, resolution = "native")
# 
# # Prefer the finest available native source tiles.
# bluertopo(aoi, resolution = "finest")
# 
# # Prefer the coarsest available native source tiles.
# bluertopo(aoi, resolution = "coarsest")
# 
# # Keep all available resolutions as candidates.
# bluertopo(aoi, resolution = "best_available")

## -----------------------------------------------------------------------------
# bluertopo(aoi, resolution = 8)
# 
# bluertopo(
#   aoi,
#   resolution = bluertopo_resolution(
#     "nearest",
#     value = 10,
#     tie = "finer"
#   )
# )

## -----------------------------------------------------------------------------
# bluertopo(
#   aoi,
#   resolution = bluertopo_resolution("between", min_m = 4, max_m = 16)
# )
# 
# bluertopo(
#   aoi,
#   resolution = bluertopo_resolution("finest_n", n = 2)
# )

## -----------------------------------------------------------------------------
# bluertopo(
#   aoi,
#   resolution = "finest",
#   coverage = "fill",
#   min_coverage = 0.95
# )
# 
# policy <- bluertopo_resolution(
#   "coverage",
#   prefer = "finest",
#   min_coverage = 0.90
# )
# 
# bluertopo(aoi, resolution = policy, coverage = "fill")

